/* eslint prefer-arrow-callback: 0 */
import { isArray, isString, isPlainObject, isFunction } from 'lodash';
import createDisplay from './createDisplay';
import { invariant, DEFAULT_DISPLAY_PARAM_KEY } from './kit';
/**
 * 统一化调用 display 的参数
 */
export default function normalizeCallDisplayArguments(arg) {
    let params;
    // [type, defaultParams]
    if (isArray(arg)) {
        params = {
            type: arg[0],
        };
        if (arg.length > 1) {
            // eslint-disable-next-line prefer-destructuring
            params[DEFAULT_DISPLAY_PARAM_KEY] = arg[1];
        }
    }
    else if (isString(arg)) {
        params = {
            type: arg,
        };
    }
    else if (isPlainObject(arg)) {
        params = arg;
    }
    else if (isFunction(arg)) {
        params = {
            type: createDisplay(function wrapFnDisplay(value, _, displayCtx) {
                const { record, recordKey } = displayCtx;
                return arg(value, record, recordKey);
            }),
        };
    }
    invariant(params &&
        ((isString(params.type) && params.type.length) ||
            isFunction(params.type)), '参数 `type` 必须为非空字符串');
    return params;
}
