import { forEach } from 'lodash';
import defaultPrefixResolver from './defaultPrefixResolver';
import { getMutable } from '../../runtime';
function getPrefixReplacer(prefixResolverMap) {
    return (relativedDsPath) => {
        let resolvedDsPath = relativedDsPath;
        let replaced = false;
        forEach(prefixResolverMap, (mapped, source) => {
            if (typeof mapped !== 'function')
                return true;
            if (source.charAt(0) === '/') {
                source = source.slice(1);
            }
            if (relativedDsPath.split('/')[1] === source) {
                resolvedDsPath = relativedDsPath.replace(`/${source}`, mapped());
                replaced = true;
                return false;
            }
            return true;
        });
        return replaced ? resolvedDsPath : defaultPrefixResolver(relativedDsPath);
    };
}
export default function getPrefixResolver() {
    // mapping
    const prefixResolver = getMutable('DS_PREFIX_RESOLVER');
    if (typeof prefixResolver === 'object') {
        return getPrefixReplacer(prefixResolver);
    }
    if (typeof prefixResolver === 'function') {
        return (dsPath) => prefixResolver(dsPath, (mapping) => {
            return getPrefixReplacer(mapping)(dsPath);
        });
    }
    // prefix
    return defaultPrefixResolver;
}
