import { cond, constant, curry, eq, identity, isArray } from 'lodash';
function wrapValue(execFunc) {
    return () => execFunc;
}
/**
 * @example
 * const func1 = () => console.log('func1');
 * const func2 = () => console.log('func2');
 *
 * const getTransformer = createGetTransformer([[true, func1], [false, func2]])
 * getTransformer(true)()
 * // => 'func1'
 */
export default function condTransform(pairs, defaults) {
    if (!isArray(pairs)) {
        return identity;
    }
    const condPairs = pairs.reduce((p, pair) => {
        let predicate;
        if (typeof pair[0] === 'function') {
            // eslint-disable-next-line prefer-destructuring
            predicate = pair[0];
        }
        else {
            predicate = curry(eq, 2)(pair[0]);
        }
        return [...p, [predicate, wrapValue(pair[1])]];
    }, []);
    condPairs.push([
        constant(true),
        wrapValue(typeof defaults === 'function' ? defaults : identity),
    ]);
    return cond(condPairs);
}
