import { arrayToMapObject } from 'bf-utils';
import { isString, mapValues, isArray } from 'lodash';
/**
 * 将数组转换为kv对象，包括子对象也转换
 * @param arr
 * @param keyField 作为 key 的字段
 * @param deepKey 未指定为递归所有字段，指定则递归具体的字段
 * @example
 * deepArrayToMapObject(
 *  [{id: 1, name: 'a', children: [{id: 2, name: 'b'}]}],
 *  id,
 *  'children'
 * )
 * // => { 1: {id: 1, name: 'a', children: { id: 2, name: 'b' }} }
 */
export default function deepArrayToMapObject(arr, keyField, deepKey) {
    let finalDeepKey;
    if (isString(deepKey) && deepKey) {
        finalDeepKey = deepKey;
    }
    return arrayToMapObject(arr, keyField, (v) => {
        return mapValues(v, (vv, kk) => {
            if (isArray(vv) && (finalDeepKey === undefined || finalDeepKey === kk)) {
                return deepArrayToMapObject(vv, keyField, deepKey);
            }
            return vv;
        });
    });
}
