import { diff } from 'deep-diff';
import { get, isArray, isPlainObject, reduce, set } from 'lodash';
import flattenObject from './flattenObject';
function prepareObject(obj) {
    if (isArray(obj)) {
        return obj.reduce((p, v, index) => (Object.assign(Object.assign({}, p), { [index]: v })), {});
    }
    return obj;
}
/**
 * 增量平铺对象
 *
 * @param prevFlattedObject 前平铺的数据
 * @param prevObject 前对象
 * @param nextObject 下一个对象
 * @param transformValue
 * @return
 */
export default function incrementalFlattenObject(prevFlattedObject = {}, prevObject = {}, nextObject, transformValue) {
    const objectifiedPrevObject = prepareObject(prevObject);
    const objectifiedNextObject = prepareObject(nextObject);
    const diffResult = diff(objectifiedPrevObject, objectifiedNextObject);
    if (!isArray(diffResult))
        return flattenObject(objectifiedNextObject, transformValue);
    let incrementalObject = {};
    const deletePaths = [];
    diffResult.forEach((d) => {
        if (d.kind === 'D') {
            deletePaths.push(d.path);
        }
        else if (d.kind === 'E' || d.kind === 'N') {
            if (d.path == null) {
                incrementalObject = d.rhs;
            }
            else {
                const parentPath = d.path.slice(0, d.path.length - 1);
                const parentData = parentPath.length
                    ? get(nextObject, parentPath)
                    : nextObject;
                if (!isArray(parentData) ||
                    !parentData.length ||
                    isPlainObject(parentData[0])) {
                    incrementalObject[d.path.join('.')] = d.rhs;
                }
                else {
                    const nextItem = parentData.slice();
                    nextItem[d.path.slice(-1)[0]] = d.rhs;
                    set(incrementalObject, parentPath, nextItem);
                }
            }
        }
        else if (d.kind === 'A') {
            const arrPath = d.path ? d.path.slice() : [];
            const nextItem = get(incrementalObject, arrPath) || get(nextObject, arrPath).slice();
            if (d.item.kind === 'D') {
                set(incrementalObject, arrPath, nextItem);
                deletePaths.push([...d.path, d.index]);
            }
            else if (d.item.kind === 'E' || d.item.kind === 'N') {
                nextItem[d.index] = d.item.rhs;
                set(incrementalObject, arrPath, nextItem);
            }
        }
    });
    const incrementalFlattedObject = flattenObject(incrementalObject, transformValue);
    const deleteStrPaths = deletePaths.map((path) => path.join('.'));
    const deletedFlattedObject = reduce(prevFlattedObject, (p, v, pathStr) => {
        if (deleteStrPaths.some((deleteStrPath) => pathStr.startsWith(deleteStrPath))) {
            return p;
        }
        p[pathStr] = v;
        return p;
    }, {});
    // assign to `deletedFlattedObject` for performance
    const nextFlattedObject = Object.assign(deletedFlattedObject, incrementalFlattedObject);
    return nextFlattedObject;
}
