import { get, identity, isArray, isObject } from 'lodash';
import { ensureArray } from 'bf-utils';
/**
 * 遍历数组，如果元素是对象，则会根据 `childrenKey` 的值进行递归遍历数组
 * 与 `traverseMapArray` 不同的是，它会保留层级结构
 *
 * @param array
 * @param iteratee
 * @param childrenKey
 * @param renameChildrenKey
 * @return
 */
export default function traverseMapArrayWithHierarchy(array, iteratee = identity, childrenKey = 'children', renameChildrenKey) {
    return ensureArray(array).reduce((p, v, i) => {
        let obj = iteratee(v, i);
        if (!isObject(obj)) {
            p.push(obj);
            return p;
        }
        if (childrenKey && isArray(get(v, childrenKey))) {
            const chilren = traverseMapArrayWithHierarchy(v[childrenKey], iteratee, childrenKey, renameChildrenKey);
            obj = Object.assign(Object.assign({}, obj), { [renameChildrenKey || childrenKey]: chilren });
        }
        p.push(obj);
        return p;
    }, []);
}
