import useEffectOnce from './useEffectOnce';
/**
 * React lifecycle hook that calls a function after the component is mounted. Use useEffectOnce if you need both a mount and unmount function.
 * @see https://github.com/streamich/react-use/blob/master/docs/useMount.md
 * @param fn
 * @example
 * ```js
 *
 * const Demo = () => {
 *   useMount(() => alert('MOUNTED'));
 *   return null;
 * };
 * ```
 */
const useMount = (fn) => {
    useEffectOnce(() => {
        fn();
    });
};
export default useMount;
