import { useRef, useEffect } from 'react';
export default function useVisibleEffect(visible, onVisible, onInvisible) {
    const visibleRef = useRef(false);
    useEffect(() => {
        if (!!visibleRef.current === !!visible) {
            return;
        }
        if (!visibleRef.current && visible && typeof onVisible === 'function') {
            onVisible();
        }
        if (visibleRef.current && !visible && typeof onInvisible === 'function') {
            onInvisible();
        }
        visibleRef.current = visible;
    }, [onInvisible, onVisible, visible]);
}
