import { filter, isArray, isArrayLike, get } from 'lodash';
import { getIndex, getNewArray } from './kit';
const arrayHelpers = {
    /**
     * 在指定位置上添加值 `value`，若原位置值存在则替换原值，返回新数组
     */
    set: (array, index, value) => {
        const newArray = getNewArray(array);
        const idx = getIndex(index);
        if (idx === null) {
            return newArray;
        }
        if (idx >= newArray.length) {
            newArray.length = idx + 1;
        }
        newArray[idx] = value;
        return newArray;
    },
    /**
     * 获取指定位置上的值
     */
    get: (array, index, notSetValue) => {
        if (!isArrayLike(array))
            return notSetValue;
        return get(array, index, notSetValue);
    },
    /**
     * 从数组中删除 index 的数据，返回新数组
     */
    delete: (array, index) => {
        const newArray = getNewArray(array);
        const idx = getIndex(index);
        if (idx === null) {
            return newArray;
        }
        newArray.splice(idx, 1);
        return newArray;
    },
    /**
     * 数组添加数据，返回新数组
     */
    push: (array, value) => {
        const newArray = getNewArray(array);
        newArray.push(value);
        return newArray;
    },
    /**
     * 返回从左到右第一个找到值的 index，不存在返回 -1
     */
    indexOf: (array, searchValue) => {
        if (!isArray(array))
            return -1;
        return array.indexOf(searchValue);
    },
};
/*  extends  */
const extendsArrayFuncs = {
    /**
     * 删除数组里的值，返回删除后的数组
     */
    deleteOf: (array, value) => {
        return filter(array, (v) => v !== value);
    },
};
export default Object.assign(Object.assign(Object.assign({}, arrayHelpers), extendsArrayFuncs), { remove: arrayHelpers.delete, removeOf: extendsArrayFuncs.deleteOf });
