"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint no-param-reassign: 0 */
const lodash_1 = require("lodash");
const kit_1 = require("./kit");
function setDisplayFlag(display) {
    Object.assign(display, {
        [kit_1.DISPLAY]: 1,
    });
}
function createSettledDisplay(display) {
    return (params) => {
        const settledDisplay = (value, record, key) => {
            return display(value, params, record, key);
        };
        setDisplayFlag(settledDisplay);
        return settledDisplay;
    };
}
function normalizeCreateDisplayArguments(...args) {
    if (typeof args[0] === 'function') {
        return {
            displayRegister: args[0],
            defaultParams: {},
        };
    }
    if (typeof args[1] === 'function') {
        return {
            displayRegister: args[1],
            defaultParams: kit_1.ensureObject(args[0]),
        };
    }
    return {
        displayRegister: args[2],
        defaultParams: kit_1.ensureObject(args[0]),
        defaultParamKey: args[1],
    };
}
function createDisplay(p1, p2, p3) {
    const { displayRegister, defaultParams, defaultParamKey, } = normalizeCreateDisplayArguments(p1, p2, p3);
    kit_1.invariant(!defaultParams.type, '`createDisplay` 参数 `defaultParams` 中不能含有 `type` 属性');
    kit_1.invariant(lodash_1.isFunction(displayRegister), '`createDisplay` 参数 `displayRegister` 必须为函数');
    const displayFn = (value, params, record, key) => {
        const finalParams = Object.assign(Object.assign({}, defaultParams), params);
        if (defaultParamKey &&
            params &&
            Object.prototype.hasOwnProperty.call(params, kit_1.DEFAULT_DISPLAY_PARAM_KEY)) {
            finalParams[defaultParamKey] = params[kit_1.DEFAULT_DISPLAY_PARAM_KEY];
        }
        const displayCtx = {
            get record() {
                return record;
            },
            get recordKey() {
                return key;
            },
        };
        const result = displayRegister(value, finalParams, displayCtx);
        return result;
    };
    const display = Object.assign(displayFn, {
        get settle() {
            return createSettledDisplay(displayFn);
        },
        get curry() {
            return () => (...args) => {
                if (args.length > 1) {
                    return display(args[1], args[0], args[2]);
                }
                return createSettledDisplay(displayFn)(args[0]);
            };
        },
        get defaultParamKey() {
            return defaultParamKey;
        },
    });
    setDisplayFlag(display);
    return display;
}
exports.default = createDisplay;
