"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
const defaultPrefixResolver_1 = __importDefault(require("./defaultPrefixResolver"));
const runtime_1 = require("../../runtime");
function getPrefixReplacer(prefixResolverMap) {
    return (relativedDsPath) => {
        let resolvedDsPath = relativedDsPath;
        let replaced = false;
        lodash_1.forEach(prefixResolverMap, (mapped, source) => {
            if (typeof mapped !== 'function')
                return true;
            if (source.charAt(0) === '/') {
                source = source.slice(1);
            }
            if (relativedDsPath.split('/')[1] === source) {
                resolvedDsPath = relativedDsPath.replace(`/${source}`, mapped());
                replaced = true;
                return false;
            }
            return true;
        });
        return replaced ? resolvedDsPath : defaultPrefixResolver_1.default(relativedDsPath);
    };
}
function getPrefixResolver() {
    // mapping
    const prefixResolver = runtime_1.getMutable('DS_PREFIX_RESOLVER');
    if (typeof prefixResolver === 'object') {
        return getPrefixReplacer(prefixResolver);
    }
    if (typeof prefixResolver === 'function') {
        return (dsPath) => prefixResolver(dsPath, (mapping) => {
            return getPrefixReplacer(mapping)(dsPath);
        });
    }
    // prefix
    return defaultPrefixResolver_1.default;
}
exports.default = getPrefixResolver;
