"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
function wrapValue(execFunc) {
    return () => execFunc;
}
/**
 * @example
 * const func1 = () => console.log('func1');
 * const func2 = () => console.log('func2');
 *
 * const getTransformer = createGetTransformer([[true, func1], [false, func2]])
 * getTransformer(true)()
 * // => 'func1'
 */
function condTransform(pairs, defaults) {
    if (!lodash_1.isArray(pairs)) {
        return lodash_1.identity;
    }
    const condPairs = pairs.reduce((p, pair) => {
        let predicate;
        if (typeof pair[0] === 'function') {
            // eslint-disable-next-line prefer-destructuring
            predicate = pair[0];
        }
        else {
            predicate = lodash_1.curry(lodash_1.eq, 2)(pair[0]);
        }
        return [...p, [predicate, wrapValue(pair[1])]];
    }, []);
    condPairs.push([
        lodash_1.constant(true),
        wrapValue(typeof defaults === 'function' ? defaults : lodash_1.identity),
    ]);
    return lodash_1.cond(condPairs);
}
exports.default = condTransform;
