"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bf_utils_1 = require("bf-utils");
const lodash_1 = require("lodash");
/**
 * 将数组转换为kv对象，包括子对象也转换
 * @param arr
 * @param keyField 作为 key 的字段
 * @param deepKey 未指定为递归所有字段，指定则递归具体的字段
 * @example
 * deepArrayToMapObject(
 *  [{id: 1, name: 'a', children: [{id: 2, name: 'b'}]}],
 *  id,
 *  'children'
 * )
 * // => { 1: {id: 1, name: 'a', children: { id: 2, name: 'b' }} }
 */
function deepArrayToMapObject(arr, keyField, deepKey) {
    let finalDeepKey;
    if (lodash_1.isString(deepKey) && deepKey) {
        finalDeepKey = deepKey;
    }
    return bf_utils_1.arrayToMapObject(arr, keyField, (v) => {
        return lodash_1.mapValues(v, (vv, kk) => {
            if (lodash_1.isArray(vv) && (finalDeepKey === undefined || finalDeepKey === kk)) {
                return deepArrayToMapObject(vv, keyField, deepKey);
            }
            return vv;
        });
    });
}
exports.default = deepArrayToMapObject;
