"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
function reduceArray(array, iteratee, initValue) {
    return array.reduce(iteratee, initValue);
}
function reducePlainObject(object, iteratee, initValue) {
    return Object.keys(object).reduce((p, key) => {
        const value = object[key];
        return iteratee(p, value, key);
    }, initValue);
}
function reduceArrayOrPlainObject(value, iteratee, initValue) {
    if (Array.isArray(value))
        return reduceArray(value, iteratee, initValue);
    if (lodash_1.isPlainObject(value))
        return reducePlainObject(value, iteratee, initValue);
    return value;
}
function flattenObjectIterator(item, parentPath, prev, transformValue) {
    if (lodash_1.isPlainObject(item) && lodash_1.isEmpty(item)) {
        if (!parentPath.length)
            return item;
        prev[parentPath.join('.')] = item;
        return prev;
    }
    // XXX 不能直接使用 reduce，如果数据为 { length: 2 }，会当做类数组，循环两次值为 undefined
    return reduceArrayOrPlainObject(item, (p, v, k) => {
        // 处理稀疏数组
        if (lodash_1.isArray(v)) {
            const tmp = lodash_1.reduce(v, (pp, vv, index) => {
                if (!(index in v))
                    return pp;
                pp[index] = vv;
                return pp;
            }, {});
            if (Object.keys(tmp).length !== v.length) {
                v = tmp;
            }
        }
        // 只兼容 object[] 的数组展开
        if (lodash_1.isArray(v) && v.length && lodash_1.isPlainObject(v[0])) {
            return lodash_1.reduce(v, (pp, obj, idx) => {
                const nextParentPath = [...parentPath, k, idx];
                return Object.assign(pp, flattenObjectIterator(obj, nextParentPath, pp, transformValue));
            }, p);
        }
        if (lodash_1.isPlainObject(v)) {
            const nextParentPath = [...parentPath, k];
            return flattenObjectIterator(v, nextParentPath, p, transformValue);
        }
        const finalPath = [...parentPath, k].join('.');
        p[finalPath] = lodash_1.isFunction(transformValue) ? transformValue(v) : v;
        return p;
    }, prev);
}
/**
 * 平铺对象，将对象转换为 key 为 path 方式
 *
 * @param object
 * @param transformValue
 * @return
 */
function flattenObject(object, transformValue) {
    return flattenObjectIterator(object, [], {}, transformValue);
}
exports.default = flattenObject;
