"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const deep_diff_1 = require("deep-diff");
const lodash_1 = require("lodash");
const flattenObject_1 = __importDefault(require("./flattenObject"));
function prepareObject(obj) {
    if (lodash_1.isArray(obj)) {
        return obj.reduce((p, v, index) => (Object.assign(Object.assign({}, p), { [index]: v })), {});
    }
    return obj;
}
/**
 * 增量平铺对象
 *
 * @param prevFlattedObject 前平铺的数据
 * @param prevObject 前对象
 * @param nextObject 下一个对象
 * @param transformValue
 * @return
 */
function incrementalFlattenObject(prevFlattedObject = {}, prevObject = {}, nextObject, transformValue) {
    const objectifiedPrevObject = prepareObject(prevObject);
    const objectifiedNextObject = prepareObject(nextObject);
    const diffResult = deep_diff_1.diff(objectifiedPrevObject, objectifiedNextObject);
    if (!lodash_1.isArray(diffResult))
        return flattenObject_1.default(objectifiedNextObject, transformValue);
    let incrementalObject = {};
    const deletePaths = [];
    diffResult.forEach((d) => {
        if (d.kind === 'D') {
            deletePaths.push(d.path);
        }
        else if (d.kind === 'E' || d.kind === 'N') {
            if (d.path == null) {
                incrementalObject = d.rhs;
            }
            else {
                const parentPath = d.path.slice(0, d.path.length - 1);
                const parentData = parentPath.length
                    ? lodash_1.get(nextObject, parentPath)
                    : nextObject;
                if (!lodash_1.isArray(parentData) ||
                    !parentData.length ||
                    lodash_1.isPlainObject(parentData[0])) {
                    incrementalObject[d.path.join('.')] = d.rhs;
                }
                else {
                    const nextItem = parentData.slice();
                    nextItem[d.path.slice(-1)[0]] = d.rhs;
                    lodash_1.set(incrementalObject, parentPath, nextItem);
                }
            }
        }
        else if (d.kind === 'A') {
            const arrPath = d.path ? d.path.slice() : [];
            const nextItem = lodash_1.get(incrementalObject, arrPath) || lodash_1.get(nextObject, arrPath).slice();
            if (d.item.kind === 'D') {
                lodash_1.set(incrementalObject, arrPath, nextItem);
                deletePaths.push([...d.path, d.index]);
            }
            else if (d.item.kind === 'E' || d.item.kind === 'N') {
                nextItem[d.index] = d.item.rhs;
                lodash_1.set(incrementalObject, arrPath, nextItem);
            }
        }
    });
    const incrementalFlattedObject = flattenObject_1.default(incrementalObject, transformValue);
    const deleteStrPaths = deletePaths.map((path) => path.join('.'));
    const deletedFlattedObject = lodash_1.reduce(prevFlattedObject, (p, v, pathStr) => {
        if (deleteStrPaths.some((deleteStrPath) => pathStr.startsWith(deleteStrPath))) {
            return p;
        }
        p[pathStr] = v;
        return p;
    }, {});
    // assign to `deletedFlattedObject` for performance
    const nextFlattedObject = Object.assign(deletedFlattedObject, incrementalFlattedObject);
    return nextFlattedObject;
}
exports.default = incrementalFlattenObject;
