"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
/**
 * 类似 lodash.pick 的方法，但是可以对属性名进行改名
 *
 * @example
 * const obj = { a: 1, b: 2, c: 3 };
 * renamePick(obj, ['a', ['b', 'd']])
 * // => { a: 1, d: 2 }
 */
function renamePick(obj, paths) {
    if (!Array.isArray(paths)) {
        paths = [paths]; // eslint-disable-line
    }
    const renameKeys = [];
    const pathsForPick = [];
    paths.forEach((path) => {
        if (Array.isArray(path)) {
            renameKeys.push(path.slice());
            pathsForPick.push(path[0]);
            return;
        }
        pathsForPick.push(path);
    });
    const r = lodash_1.pick(obj, pathsForPick);
    renameKeys.forEach(([from, to]) => {
        r[to] = r[from];
        if (from !== to) {
            delete r[from];
        }
    });
    return r;
}
exports.default = renamePick;
