"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
const bf_utils_1 = require("bf-utils");
/**
 * 遍历数组，如果元素是对象，则会根据 `childrenKey` 的值进行递归遍历数组
 * 与 `traverseMapArray` 不同的是，它会保留层级结构
 *
 * @param array
 * @param iteratee
 * @param childrenKey
 * @param renameChildrenKey
 * @return
 */
function traverseMapArrayWithHierarchy(array, iteratee = lodash_1.identity, childrenKey = 'children', renameChildrenKey) {
    return bf_utils_1.ensureArray(array).reduce((p, v, i) => {
        let obj = iteratee(v, i);
        if (!lodash_1.isObject(obj)) {
            p.push(obj);
            return p;
        }
        if (childrenKey && lodash_1.isArray(lodash_1.get(v, childrenKey))) {
            const chilren = traverseMapArrayWithHierarchy(v[childrenKey], iteratee, childrenKey, renameChildrenKey);
            obj = Object.assign(Object.assign({}, obj), { [renameChildrenKey || childrenKey]: chilren });
        }
        p.push(obj);
        return p;
    }, []);
}
exports.default = traverseMapArrayWithHierarchy;
