"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
/**
 * React lifecycle hook that runs an effect only once.
 *
 * @see https://github.com/streamich/react-use/blob/master/docs/useEffectOnce.md
 * @param effect
 * @example
 * ```
 * const Demo = () => {
 *   useEffectOnce(() => {
 *     console.log('Running effect once on mount')
 *
 *     return () => {
 *       console.log('Running clean-up of effect on unmount')
 *     }
 *   });
 *
 *   return null;
 * };
 * ```
 */
const useEffectOnce = (effect) => {
    // eslint-disable-next-line react-hooks/exhaustive-deps
    react_1.useEffect(effect, []);
};
exports.default = useEffectOnce;
