"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const useEffectOnce_1 = __importDefault(require("./useEffectOnce"));
/**
 * React lifecycle hook that calls a function after the component is mounted. Use useEffectOnce if you need both a mount and unmount function.
 * @see https://github.com/streamich/react-use/blob/master/docs/useMount.md
 * @param fn
 * @example
 * ```js
 *
 * const Demo = () => {
 *   useMount(() => alert('MOUNTED'));
 *   return null;
 * };
 * ```
 */
const useMount = (fn) => {
    useEffectOnce_1.default(() => {
        fn();
    });
};
exports.default = useMount;
