"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
const kit_1 = require("./kit");
const arrayHelpers = {
    /**
     * 在指定位置上添加值 `value`，若原位置值存在则替换原值，返回新数组
     */
    set: (array, index, value) => {
        const newArray = kit_1.getNewArray(array);
        const idx = kit_1.getIndex(index);
        if (idx === null) {
            return newArray;
        }
        if (idx >= newArray.length) {
            newArray.length = idx + 1;
        }
        newArray[idx] = value;
        return newArray;
    },
    /**
     * 获取指定位置上的值
     */
    get: (array, index, notSetValue) => {
        if (!lodash_1.isArrayLike(array))
            return notSetValue;
        return lodash_1.get(array, index, notSetValue);
    },
    /**
     * 从数组中删除 index 的数据，返回新数组
     */
    delete: (array, index) => {
        const newArray = kit_1.getNewArray(array);
        const idx = kit_1.getIndex(index);
        if (idx === null) {
            return newArray;
        }
        newArray.splice(idx, 1);
        return newArray;
    },
    /**
     * 数组添加数据，返回新数组
     */
    push: (array, value) => {
        const newArray = kit_1.getNewArray(array);
        newArray.push(value);
        return newArray;
    },
    /**
     * 返回从左到右第一个找到值的 index，不存在返回 -1
     */
    indexOf: (array, searchValue) => {
        if (!lodash_1.isArray(array))
            return -1;
        return array.indexOf(searchValue);
    },
};
/*  extends  */
const extendsArrayFuncs = {
    /**
     * 删除数组里的值，返回删除后的数组
     */
    deleteOf: (array, value) => {
        return lodash_1.filter(array, (v) => v !== value);
    },
};
exports.default = Object.assign(Object.assign(Object.assign({}, arrayHelpers), extendsArrayFuncs), { remove: arrayHelpers.delete, removeOf: extendsArrayFuncs.deleteOf });
