"use strict";
/* eslint-disable no-plusplus */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * 将 object 转换为 querystring
 * @example
 * objectToQuerystring({a: 1, b: 2}) // a=1&b=2
 */
function objectToQuerystring(obj, sep = '&', eq = '=') {
    function stringifyPrimitive(v) {
        if (typeof v === 'string') {
            return v;
        }
        if (typeof v === 'number' && Number.isFinite(v)) {
            return String(v);
        }
        if (typeof v === 'boolean') {
            return v ? 'true' : 'false';
        }
        return '';
    }
    const encode = encodeURIComponent;
    if (obj !== null && typeof obj === 'object') {
        const keys = Object.keys(obj);
        const len = keys.length;
        const flast = len - 1;
        let fields = '';
        for (let i = 0; i < len; ++i) {
            const k = keys[i];
            const v = obj[k];
            const ks = encode(stringifyPrimitive(k)) + eq;
            if (Array.isArray(v)) {
                const vlen = v.length;
                const vlast = vlen - 1;
                for (let j = 0; j < vlen; ++j) {
                    fields += ks + encode(stringifyPrimitive(v[j]));
                    if (j < vlast) {
                        fields += sep;
                    }
                }
                if (vlen && i < flast) {
                    fields += sep;
                }
            }
            else {
                fields += ks + encode(stringifyPrimitive(v));
                if (i < flast) {
                    fields += sep;
                }
            }
        }
        return fields;
    }
    return '';
}
exports.default = objectToQuerystring;
