/**
 * 用于从数据中获取需要的值
 *
 * @example
 * extract({ fn: (value, record) => record.a + record.b })(undefined, { a: 1, b: 2 })
 * // => 3
 */
export declare const extract: import("./types").SettledDisplay;
/**
 * 显示不换行
 *
 * @example
 * nowrap()('text')
 * // => <div style={ 'white-space': 'nowrap' }>text</div>
 */
export declare const nowrap: import("./types").Display;
/**
 * 格式化常量数据
 *
 * @example
 * const map = { m: '男', f: '女' };
 * consts({ map })('m');
 * // => '男'
 */
export declare const consts: import("./types").SettledDisplay;
/**
 * 若数据为 null 或 undefined，格式化为默认值
 *
 * @return {Function}
 * @example
 * defaults({ defaultValue: '-' })(null)
 * // => '-'
 */
export declare const defaults: import("./types").SettledDisplay;
/**
 * 格式化时间
 *
 * @return {Function}
 * @example
 * formatTime()(1471564800000); // '2016-08-19 08:00:00'
 */
export declare const formatTime: import("./types").SettledDisplay;
/**
 * 格式化日期
 *
 * @return {Function}
 * @example
 * formatDate()(1471564800000); // '2016-08-19'
 */
export declare const formatDate: import("./types").SettledDisplay;
/**
 * 格式化数值成整数
 * @param  {Object} conf
 * @param  {Function} [conf.formatNaN] - 值解析为 NaN 时输出的函数
 * @param  {Function} [conf.preprocess] - 预处理值
 * @param  {Function} [conf.format] - 格式化输出，参考 accounting 文档
 * @return {String}
 */
export declare const integer: import("./types").SettledDisplay;
/**
 * 格式化金额，金额单位为元
 * @param  {Object} conf
 * @param  {Function} [conf.formatNaN] - 值解析为 NaN 时输出的函数
 * @param  {Function} [conf.preprocess] - 预处理值
 * @param  {Number} [conf.precision=2] - 小数精度，默认为 2
 * @param  {String} [conf.symbol=''] - 金额单位，默认为空
 * @param  {Function} [conf.format] - 格式化输出，参考 accounting 文档
 * @return {String}
 */
export declare const money: import("./types").SettledDisplay;
declare const _default: {
    consts: import("./types").SettledDisplay;
    defaults: import("./types").SettledDisplay;
    formatDate: import("./types").SettledDisplay;
    formatTime: import("./types").SettledDisplay;
    integer: import("./types").SettledDisplay;
    money: import("./types").SettledDisplay;
};
export default _default;
