export interface IDSError extends Error {
    /**
     * 网络请求失败或跨域请求服务器无 CORS 头
     */
    isNetworkError: boolean;
    /**
     * HTTP 请求不为 2xx 或 isNetworkError = true 是为 true
     */
    isHttpError: boolean;
    /**
     * HTTP 状态码
     */
    httpStatus?: number;
    /**
     * HTTP 返回 200 但数据不能解析成 JSON 或解析结果不含 status 字段
     */
    isParsedError: boolean;
    /**
     * 业务 status
     * 当请求数据成功解析成标准返回格式且 status 不为 0
     */
    status?: number;
    /**
     * 返回 body 字符串值
     */
    responseBodyText?: string;
}
export interface DSRequestParams {
    [key: string]: any;
}
export interface DSRequestConfig {
    method?: string;
    getDataFromResponse?: (response: any) => any;
    headers?: Record<string, string>;
    fetcherInit?: Record<string, any>;
}
export interface NormalizedDSArguments {
    dsPath: string;
    params: DSRequestParams;
    config: DSRequestConfig;
}
export interface DSResponseData {
    status: number;
    data?: any;
    message?: string;
}
export declare type DSArgument = string | [string, DSRequestParams?, DSRequestConfig?] | ({
    dsPath: string;
    params?: DSRequestParams;
} & DSRequestConfig);
