import { DSRequestParams } from '../ds/types';
import DSError from '../ds/Error';
export interface Mutables {
    DS_PREFIX: string;
    DS_PREFIX_RESOLVER: {
        [prefix: string]: () => string;
    } | ((dsPath: string, prefixReplacer: (mapping: Record<string, () => string>) => string) => string) | void;
    DS_CUSTOM_HEADERS_RESOLVER: ((dsPath: string, resolvedUrl: string) => Record<string, string> | void) | void;
    DS_DEFAULT_ERROR_MESSAGE: string;
    DS_UNAUTHORIZED_CALLBACK: (data: any) => string;
    /**
     * @deprecated
     */
    DS_ON_REQUEST_START: ((mark: {
        url: string;
        dsPath: string;
        params: DSRequestParams;
        id: string;
    }) => void) | void;
    /**
     * @deprecated
     */
    DS_ON_REQUEST_END: ((error: DSError | undefined, data: any, mark: {
        url: string;
        dsPath: string;
        params: DSRequestParams;
        id: string;
    }) => void) | void;
    DATE_FORMAT: string;
    DATE_MONTH_FORMAT: string;
    TIME_FORMAT: string;
    TABLE_DEFAULT_LOAD_FAIL_MESSAGE: string;
    TABLE_MORE_OVERLAY_CLASSNAME: string;
    FORMAT_BOOLEAN_TO_STRING_TRUE: any;
    FORMAT_BOOLEAN_TO_STRING_FALSE: any;
    TEXT_DANGER_COLOR: string;
    MONEY_PRESET_UNIT_CENT: boolean;
    [key: string]: any;
}
/**
 * ds 请求 URL 的前缀
 *
 * @example
 * ds('/ds/user/get') // POST /ds/user/get
 * config('DS_PREFIX', '/ds')
 * ds('/user/get') // POST /ds/user/get
 */
export declare const DS_PREFIX: Mutables['DS_PREFIX'];
/**
 * ds 请求解析 URL 前缀
 *
 * @note 设置值时将忽略 DS_PREFIX 配置
 * @example
 * config('DS_PREFIX_RESOLVER', { '/user': 'http://example.com/api/user' })
 * ds('/user/get') // POST http://example.com/api/user/get
 */
export declare const DS_PREFIX_RESOLVER: Mutables['DS_PREFIX_RESOLVER'];
/**
 * ds 请求设置自定义请求 headers
 *
 * @example
 * config('DS_CUSTOM_HEADERS_RESOLVER', (url) => ({ swimlane: 'DEV' }))
 */
export declare const DS_CUSTOM_HEADERS_RESOLVER: Mutables['DS_CUSTOM_HEADERS_RESOLVER'];
/**
 * ds 请求失败（ HTTP 错误 ）的错误消息
 */
export declare const DS_DEFAULT_ERROR_MESSAGE: Mutables['DS_DEFAULT_ERROR_MESSAGE'];
/**
 * ds 接到 401 的处理方法，返回值将作为错误消息
 */
export declare const DS_UNAUTHORIZED_CALLBACK: Mutables['DS_UNAUTHORIZED_CALLBACK'];
/**
 * 在 ds 请求开始时执行回调
 * @deprecated
 */
export declare const DS_ON_REQUEST_START: Mutables['DS_ON_REQUEST_START'];
/**
 * 在 ds 请求完成执行回调
 * @deprecated
 */
export declare const DS_ON_REQUEST_END: Mutables['DS_ON_REQUEST_END'];
/**
 * 格式化成日期字符串的格式
 * 格式参考 https://momentjs.com/docs/
 */
export declare const DATE_FORMAT: Mutables['DATE_FORMAT'];
/**
 * 格式化成日期字符串的格式，日期精确到月
 * 格式参考 https://momentjs.com/docs/
 */
export declare const DATE_MONTH_FORMAT: Mutables['DATE_MONTH_FORMAT'];
/**
 * 格式化成时间字符串的格式
 * 格式参考 https://momentjs.com/docs/
 */
export declare const TIME_FORMAT: Mutables['TIME_FORMAT'];
/**
 * 表格加载失败的文案
 */
export declare const TABLE_DEFAULT_LOAD_FAIL_MESSAGE: Mutables['TABLE_DEFAULT_LOAD_FAIL_MESSAGE'];
/**
 * 报表操作项更多的样式名
 */
export declare const TABLE_MORE_OVERLAY_CLASSNAME: Mutables['TABLE_MORE_OVERLAY_CLASSNAME'];
/**
 * 将布尔真值格式化成的内容
 */
export declare const FORMAT_BOOLEAN_TO_STRING_TRUE: Mutables['FORMAT_BOOLEAN_TO_STRING_TRUE'];
/**
 * 将布尔假值格式化成的内容
 */
export declare const FORMAT_BOOLEAN_TO_STRING_FALSE: Mutables['FORMAT_BOOLEAN_TO_STRING_FALSE'];
/**
 * 文字或链接为警告色的颜色色值
 */
export declare const TEXT_DANGER_COLOR: Mutables['TEXT_DANGER_COLOR'];
/**
 * 预格式化金额时，金额的单位为“分”，而非默认的元
 */
export declare const MONEY_PRESET_UNIT_CENT: Mutables['MONEY_PRESET_UNIT_CENT'];
