import { EffectCallback } from 'react';
/**
 * React lifecycle hook that runs an effect only once.
 *
 * @see https://github.com/streamich/react-use/blob/master/docs/useEffectOnce.md
 * @param effect
 * @example
 * ```
 * const Demo = () => {
 *   useEffectOnce(() => {
 *     console.log('Running effect once on mount')
 *
 *     return () => {
 *       console.log('Running clean-up of effect on unmount')
 *     }
 *   });
 *
 *   return null;
 * };
 * ```
 */
declare const useEffectOnce: (effect: EffectCallback) => void;
export default useEffectOnce;
